==> mx-packageinstaller-pkglist_19.09.02.tar.xz: mx-packageinstaller-pkglist/lxde.pm <==
<?xml version="1.0"?>
<app>

<category>
Desktop Environments
</category>

<name>
LXDE
</name>

<description>
   <am>basic install of LXDE</am>
   <ar>basic install of LXDE</ar>
   <bg>basic install of LXDE</bg>
   <ca>Instal·lació bàsica de LXDE</ca>
   <cs>basic install of LXDE</cs>
   <da>grundlæggende installation af LXDE</da>
   <de>Grundinstallation von LXDE</de>
   <el>βασική εγκατάσταση του LXDE</el>
   <en>basic install of LXDE</en>
   <es>Instalación mínima de LXDE</es>
   <et>basic install of LXDE</et>
   <eu>basic install of LXDE</eu>
   <fa>basic install of LXDE</fa>
   <fi>LXDE-työpöydän perusasennus</fi>
   <fr>Installation de base du bureau LXDE</fr>
   <he_IL>basic install of LXDE</he_IL>
   <hi>basic install of LXDE</hi>
   <hr>basic install of LXDE</hr>
   <hu>basic install of LXDE</hu>
   <id>basic install of LXDE</id>
   <is>basic install of LXDE</is>
   <it>installazione base di LXDE</it>
   <ja_JP>basic install of LXDE</ja_JP>
   <ja>basic install of LXDE</ja>
   <kk>basic install of LXDE</kk>
   <ko>basic install of LXDE</ko>
   <lt>basic install of LXDE</lt>
   <mk>basic install of LXDE</mk>
   <nb>basic install of LXDE</nb>
   <nl>basisinstallatie van LXDE</nl>
   <pl>podstawowa instalacja LXDE</pl>
   <pt_BR>Instalação básica do Ambiente de Trabalho LXDE</pt_BR>
   <pt>Instalação básica do Ambiente de Trabalho LXDE</pt>
   <ro>basic install of LXDE</ro>
   <ru>Базовая установка LXDE</ru>
   <sk>basic install of LXDE</sk>
   <sl>basic install of LXDE</sl>
   <sq>basic install of LXDE</sq>
   <sr>basic install of LXDE</sr>
   <sv>enkel installation av LXDE</sv>
   <tr>basic install of LXDE</tr>
   <uk>базовий набір стільниці LXDE</uk>
   <zh_CN>basic install of LXDE</zh_CN>
   <zh_TW>basic install of LXDE</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/000/519/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
lxde
lxtask
lxlauncher
lxmusic
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
lxde
lxappearance-obconf
lxsession-edit
lxterminal
lxde-core
lxde-icon-theme
lxinput
lxlauncher
lxtask
lxmusic
lxpanel
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.12.04.tar.xz: mx-packageinstaller-pkglist/lxde.pm <==
<?xml version="1.0"?>
<app>

<category>
Desktop Environments
</category>

<name>
LXDE
</name>

<description>
   <am>basic install of LXDE</am>
   <ar>basic install of LXDE</ar>
   <bg>basic install of LXDE</bg>
   <bn>basic install of LXDE</bn>
   <ca>Instal·lació bàsica de LXDE</ca>
   <cs>basic install of LXDE</cs>
   <da>grundlæggende installation af LXDE</da>
   <de>Grundinstallation von LXDE</de>
   <el>βασική εγκατάσταση του LXDE</el>
   <en>basic install of LXDE</en>
   <es>Instalación mínima de LXDE</es>
   <et>basic install of LXDE</et>
   <eu>basic install of LXDE</eu>
   <fa>basic install of LXDE</fa>
   <fil_PH>basic install of LXDE</fil_PH>
   <fi>LXDE-työpöydän perusasennus</fi>
   <fr>Installation de base du bureau LXDE</fr>
   <he_IL>basic install of LXDE</he_IL>
   <hi>basic install of LXDE</hi>
   <hr>basic install of LXDE</hr>
   <hu>basic install of LXDE</hu>
   <id>basic install of LXDE</id>
   <is>basic install of LXDE</is>
   <it>installazione base di LXDE</it>
   <ja_JP>basic install of LXDE</ja_JP>
   <ja>basic install of LXDE</ja>
   <kk>basic install of LXDE</kk>
   <ko>basic install of LXDE</ko>
   <lt>basic install of LXDE</lt>
   <mk>basic install of LXDE</mk>
   <mr>basic install of LXDE</mr>
   <nb>basic install of LXDE</nb>
   <nl>basisinstallatie van LXDE</nl>
   <pl>podstawowa instalacja LXDE</pl>
   <pt_BR>Instalação básica do Ambiente de Trabalho LXDE</pt_BR>
   <pt>Instalação básica do Ambiente de Trabalho LXDE</pt>
   <ro>basic install of LXDE</ro>
   <ru>Базовая установка LXDE</ru>
   <sk>basic install of LXDE</sk>
   <sl>Osnovna namestitev LXDE</sl>
   <sq>basic install of LXDE</sq>
   <sr>basic install of LXDE</sr>
   <sv>enkel installation av LXDE</sv>
   <tr>LXDE temel kurulumu</tr>
   <uk>базовий набір стільниці LXDE</uk>
   <vi>basic install of LXDE</vi>
   <zh_CN>basic install of LXDE</zh_CN>
   <zh_TW>basic install of LXDE</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/000/519/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
lxde
lxtask
lxlauncher
lxmusic
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
lxde
lxappearance-obconf
lxsession-edit
lxterminal
lxde-core
lxde-icon-theme
lxinput
lxlauncher
lxtask
lxmusic
lxpanel
</uninstall_package_names>
</app>
